@@ -134,7 +134,7 @@ class UpdateConfigs(UpdateLogger):
                           map(lambda x: (x, pwd.getpwnam(x).pw_dir),
                               getPasswdUsers())))
 
-    def _setClMergePkg(self, clVars, category, nameProgram):
+    def _setClMergePkg(self, clVars, category, nameProgram, slot=None):
         """
         Установить переменную cl_merge_pkg в зависимости от category и
         nameProgram
@@ -148,8 +148,12 @@ class UpdateConfigs(UpdateLogger):
                                       glob.glob('/var/db/pkg/*/*')))),
                        True)
         else:
-            clVars.Set("cl_merge_pkg", ["%s/%s" % (category, nameProgram)],
-                       True)
+            if slot:
+                clVars.Set("cl_merge_pkg", ["%s/%s:%s" % (category,
+                    nameProgram, slot)], True)
+            else:
+                clVars.Set("cl_merge_pkg", ["%s/%s" % (category, nameProgram)],
+                           True)
         clVars.Set("cl_merge_set", "on", True)
 
     def updateDesktopConfig(self, nameProgram, version, slot, category,
@@ -244,7 +248,10 @@ class UpdateConfigs(UpdateLogger):
                 # остальные пакеты настраиваются в корень
                 clVars.Set("cl_root_path_next", '/', True)
 
-            self._setClMergePkg(clVars, category, nameProgram)
+            if self.clVars.Get('core.cl_core_pkg_slot_opt') != "all":
+                self._setClMergePkg(clVars, category, nameProgram, slot)
+            else:
+                self._setClMergePkg(clVars, category, nameProgram)
             clVars.Set("cl_action", 'merge', True)
             clVars.Set("cl_verbose_set", verbose, True)
             clVars.Set("cl_dispatch_conf", dispatchConf, True)
