@@ -20,6 +20,7 @@ import re
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.core.server.loaded_methods import LoadedMethods
 from calculate.core.server.func import uniq
+from calculate.lib.utils.files import readFile
 
 _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
@@ -41,7 +42,7 @@ class VariableClCoreGroup(Variable):
     def choice(self):
         group_rights = self.Get('cl_core_group_rights_path')
 
-        t = open(group_rights, 'r').read()
+        t = readFile(group_rights)
         result = []
         for line in t.splitlines():
             words = line.split()
@@ -65,7 +66,7 @@ class VariableClCoreGroup(Variable):
 
         if group == 'all':
             return
-        t = open(group_rights, 'r').read()
+        t = readFile(group_rights)
         find = False
         for line in t.splitlines():
             words = line.split()
@@ -104,7 +105,7 @@ class VariableClCoreGroupRights(Variable):
         group_name = self.Get('cl_core_group')
         group_rights = self.Get('cl_core_group_rights_path')
 
-        t = open(group_rights, 'r').read()
+        t = readFile(group_rights)
         results = []
         for line in t.splitlines():
             words = line.split(' ', 1)
